==> distribution-6.17.1.zip: drr/standards/iosco/cde/version1/execution/reports/ConfirmedRule.java <==
package drr.standards.iosco.cde.version1.execution.reports;

import cdm.event.workflow.EventTimestamp;
import cdm.event.workflow.EventTimestampQualificationEnum;
import cdm.event.workflow.WorkflowStep;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.ConfirmationMethodEnum;
import drr.regulation.common.ReportableInformation;
import drr.regulation.common.TransactionReportInstruction;
import drr.standards.iso.ConfirmationEnum;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

@ImplementedBy(ConfirmedRule.ConfirmedRuleDefault.class)
public abstract class ConfirmedRule implements ReportFunction<TransactionReportInstruction, ConfirmationEnum> {

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public ConfirmationEnum evaluate(TransactionReportInstruction input) {
		ConfirmationEnum output = doEvaluate(input);
		
		return output;
	}

	protected abstract ConfirmationEnum doEvaluate(TransactionReportInstruction input);

	public static class ConfirmedRuleDefault extends ConfirmedRule {
		@Override
		protected ConfirmationEnum doEvaluate(TransactionReportInstruction input) {
			ConfirmationEnum output = null;
			return assignOutput(output, input);
		}
		
		protected ConfirmationEnum assignOutput(ConfirmationEnum output, TransactionReportInstruction input) {
			if (notEqual(MapperS.of(input).<WorkflowStep>map("getOriginatingWorkflowStep", transactionReportInstruction -> transactionReportInstruction.getOriginatingWorkflowStep()).<EventTimestamp>mapC("getTimestamp", workflowStep -> workflowStep.getTimestamp()).<EventTimestampQualificationEnum>map("getQualification", eventTimestamp -> eventTimestamp.getQualification()), MapperS.of(EventTimestampQualificationEnum.CONFIRMATION_DATE_TIME), CardinalityOperator.All).or(areEqual(MapperS.of(input).<ReportableInformation>map("getReportableInformation", transactionReportInstruction -> transactionReportInstruction.getReportableInformation()).<ConfirmationMethodEnum>map("getConfirmationMethod", reportableInformation -> reportableInformation.getConfirmationMethod()), MapperS.of(ConfirmationMethodEnum.NOT_CONFIRMED), CardinalityOperator.All)).getOrDefault(false)) {
				output = ConfirmationEnum.NCNF;
			} else {
				output = MapperS.of(input)
					.mapSingleToItem(item -> {
						if (areEqual(item.<ReportableInformation>map("getReportableInformation", transactionReportInstruction -> transactionReportInstruction.getReportableInformation()).<ConfirmationMethodEnum>map("getConfirmationMethod", reportableInformation -> reportableInformation.getConfirmationMethod()), MapperS.of(ConfirmationMethodEnum.ELECTRONIC), CardinalityOperator.All).getOrDefault(false)) {
							return MapperS.of(ConfirmationEnum.ECNF);
						}
						if (areEqual(item.<ReportableInformation>map("getReportableInformation", transactionReportInstruction -> transactionReportInstruction.getReportableInformation()).<ConfirmationMethodEnum>map("getConfirmationMethod", reportableInformation -> reportableInformation.getConfirmationMethod()), MapperS.of(ConfirmationMethodEnum.NON_ELECTRONIC), CardinalityOperator.All).getOrDefault(false)) {
							return MapperS.of(ConfirmationEnum.YCNF);
						}
						return MapperS.<ConfirmationEnum>ofNull();
					}).get();
			}
			
			return output;
		}
	}
}

==> distribution-6.24.0.zip: drr/standards/iosco/cde/version1/execution/reports/ConfirmedRule.java <==
package drr.standards.iosco.cde.version1.execution.reports;

import cdm.event.workflow.EventTimestamp;
import cdm.event.workflow.EventTimestampQualificationEnum;
import cdm.event.workflow.WorkflowStep;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.ConfirmationMethodEnum;
import drr.regulation.common.ReportableInformation;
import drr.regulation.common.TransactionReportInstruction;
import drr.standards.iso.ConfirmationEnum;

import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.*;

@ImplementedBy(ConfirmedRule.ConfirmedRuleDefault.class)
public abstract class ConfirmedRule implements ReportFunction<TransactionReportInstruction, ConfirmationEnum> {

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public ConfirmationEnum evaluate(TransactionReportInstruction input) {
		ConfirmationEnum output = doEvaluate(input);
		
		return output;
	}

	protected abstract ConfirmationEnum doEvaluate(TransactionReportInstruction input);

	public static class ConfirmedRuleDefault extends ConfirmedRule {
		@Override
		protected ConfirmationEnum doEvaluate(TransactionReportInstruction input) {
			ConfirmationEnum output = null;
			return assignOutput(output, input);
		}
		
		protected ConfirmationEnum assignOutput(ConfirmationEnum output, TransactionReportInstruction input) {
			if (notEqual(MapperS.of(input).<WorkflowStep>map("getOriginatingWorkflowStep", transactionReportInstruction -> transactionReportInstruction.getOriginatingWorkflowStep()).<EventTimestamp>mapC("getTimestamp", workflowStep -> workflowStep.getTimestamp()).<EventTimestampQualificationEnum>map("getQualification", eventTimestamp -> eventTimestamp.getQualification()), MapperS.of(EventTimestampQualificationEnum.CONFIRMATION_DATE_TIME), CardinalityOperator.All).orNullSafe(areEqual(MapperS.of(input).<ReportableInformation>map("getReportableInformation", transactionReportInstruction -> transactionReportInstruction.getReportableInformation()).<ConfirmationMethodEnum>map("getConfirmationMethod", reportableInformation -> reportableInformation.getConfirmationMethod()), MapperS.of(ConfirmationMethodEnum.NOT_CONFIRMED), CardinalityOperator.All)).getOrDefault(false)) {
				output = ConfirmationEnum.NCNF;
			} else {
				output = MapperS.of(input)
					.mapSingleToItem(item -> {
						if (areEqual(item.<ReportableInformation>map("getReportableInformation", transactionReportInstruction -> transactionReportInstruction.getReportableInformation()).<ConfirmationMethodEnum>map("getConfirmationMethod", reportableInformation -> reportableInformation.getConfirmationMethod()), MapperS.of(ConfirmationMethodEnum.ELECTRONIC), CardinalityOperator.All).getOrDefault(false)) {
							return MapperS.of(ConfirmationEnum.ECNF);
						}
						if (areEqual(item.<ReportableInformation>map("getReportableInformation", transactionReportInstruction -> transactionReportInstruction.getReportableInformation()).<ConfirmationMethodEnum>map("getConfirmationMethod", reportableInformation -> reportableInformation.getConfirmationMethod()), MapperS.of(ConfirmationMethodEnum.NON_ELECTRONIC), CardinalityOperator.All).getOrDefault(false)) {
							return MapperS.of(ConfirmationEnum.YCNF);
						}
						return MapperS.<ConfirmationEnum>ofNull();
					}).get();
			}
			
			return output;
		}
	}
}
